Welcome to miar's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   authors
   history
   index

* :ref:`genindex`

=====
Modules
=====
.. automodule:: miar.measures
   :members:
   :undoc-members:
   :show-inheritance:




